package
Version:
v0.4.0
Opens a new window with list of versions in this module.
Published: May 25, 2026
License: MIT
Opens a new window with license information.
Imports: 13
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Execute runs the root command.
func SetVersionInfo(version, commit, date string)
SetVersionInfo sets the build version information from main.go ldflags.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.