Documentation
¶
Index ¶
- func Build(cfg *config.Config, project string, force bool) (string, error)
- func Exec(project, workdir string) error
- func ImageExists(tag string) bool
- func ImageTag(project, agentName, dockerfile string) string
- func RenderDockerfile(cfg *config.Config) (string, error)
- func Run(cfg *config.Config, project, workdir, imageTag string, extraArgs []string) error
- type RenderData
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ImageExists ¶
ImageExists checks if a Docker image with the given tag exists locally.
func ImageTag ¶
ImageTag computes the image tag for a project from the rendered Dockerfile and embedded dotfile contents.
func RenderDockerfile ¶
RenderDockerfile generates the full Dockerfile content from a config.
Types ¶
type RenderData ¶
type RenderData struct {
ToolInstructions []string // rendered tool Dockerfile lines
RootSteps []string // raw root-level Dockerfile steps (pre-tools)
CustomSteps []string // raw custom Dockerfile steps
AgentInstall string // agent install RUN command
AgentExtraEnv []string // agent extra ENV lines ("KEY=VALUE")
Entrypoint string // JSON array for ENTRYPOINT
ToolEnvVars []string // sorted "KEY=VALUE" lines from tools
ToolPath string // pre-computed PATH value
NpmConfig string // npm .npmrc setup (empty if no nodejs)
}
RenderData holds all values injected into the Dockerfile template.
Click to show internal directories.
Click to hide internal directories.